# encoding: utf-8
"""
Extra capabilities for IPython
"""

#-----------------------------------------------------------------------------
#  Copyright (C) 2008-2011  The IPython Development Team
#
#  Distributed under the terms of the BSD License.  The full license is in
#  the file COPYING, distributed as part of this software.
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# Imports
#-----------------------------------------------------------------------------

from IPython.lib.security import passwd

#-----------------------------------------------------------------------------
# Code
#-----------------------------------------------------------------------------
